@@ -22,7 +22,7 @@
 #define ORTP_PORT_H
 
 
-#if !defined(WIN32) && !defined(_WIN32_WCE)
+#if !defined(_WIN32) && !defined(_WIN32_WCE)
 /********************************/
 /* definitions for UNIX flavour */
 /********************************/
@@ -53,9 +53,7 @@
 
 #include <sys/time.h>
 
-#ifdef ORTP_INET6
 #include <netdb.h>
-#endif
 
 typedef int ortp_socket_t;
 typedef pthread_t ortp_thread_t;
@@ -76,6 +74,7 @@ typedef pthread_cond_t ortp_cond_t;
 #endif
 
 #define ORTP_PUBLIC
+#define ORTP_INLINE			inline
 
 #ifdef __cplusplus
 extern "C"
@@ -83,7 +82,8 @@ extern "C"
 #endif
 
 int __ortp_thread_join(ortp_thread_t thread, void **ptr);
-int __ortp_thread_create(pthread_t *thread, pthread_attr_t *attr, void * (*routine)(void*), void *arg);
+int __ortp_thread_create(ortp_thread_t *thread, pthread_attr_t *attr, void * (*routine)(void*), void *arg);
+unsigned long __ortp_thread_self(void);
 
 #ifdef __cplusplus
 }
@@ -91,6 +91,7 @@ int __ortp_thread_create(pthread_t *thread, pthread_attr_t *attr, void * (*routi
 
 #define ortp_thread_create	__ortp_thread_create
 #define ortp_thread_join	__ortp_thread_join
+#define ortp_thread_self	__ortp_thread_self
 #define ortp_thread_exit	pthread_exit
 #define ortp_mutex_init		pthread_mutex_init
 #define ortp_mutex_lock		pthread_mutex_lock
@@ -117,24 +118,42 @@ int __ortp_thread_create(pthread_t *thread, pthread_attr_t *attr, void * (*routi
 /*********************************/
 
 #include <stdio.h>
+#define _CRT_RAND_S
 #include <stdlib.h>
 #include <stdarg.h>
 #include <winsock2.h>
 #include <ws2tcpip.h>
+#ifdef _MSC_VER
+#include <io.h>
+#endif
+
+#if defined(__MINGW32__) || !defined(WINAPI_FAMILY_PARTITION) || !defined(WINAPI_PARTITION_DESKTOP)
+#define ORTP_WINDOWS_DESKTOP 1
+#elif defined(WINAPI_FAMILY_PARTITION)
+#if defined(WINAPI_PARTITION_DESKTOP) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)
+#define ORTP_WINDOWS_DESKTOP 1
+#elif defined(WINAPI_PARTITION_PHONE_APP) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_PHONE_APP)
+#define ORTP_WINDOWS_PHONE 1
+#elif defined(WINAPI_PARTITION_APP) && WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_APP)
+#define ORTP_WINDOWS_UNIVERSAL 1
+#endif
+#endif
 
 #ifdef _MSC_VER
+#ifdef ORTP_STATIC
+#define ORTP_PUBLIC
+#else
 #ifdef ORTP_EXPORTS
 #define ORTP_PUBLIC	__declspec(dllexport)
-#else 
+#else
 #define ORTP_PUBLIC	__declspec(dllimport)
 #endif
+#endif
 #pragma push_macro("_WINSOCKAPI_")
 #ifndef _WINSOCKAPI_
 #define _WINSOCKAPI_
 #endif
 
-#define strtok_r strtok_s
-
 typedef  unsigned __int64 uint64_t;
 typedef  __int64 int64_t;
 typedef  unsigned short uint16_t;
@@ -150,21 +169,20 @@ ORTP_PUBLIC char* strtok_r(char *str, const char *delim, char **nextp);
 #endif
 
 #define vsnprintf	_vsnprintf
-#define srandom		srand
-#define random		rand
 
 typedef SOCKET ortp_socket_t;
-#ifdef WINAPI_FAMILY_PHONE_APP
-typedef CONDITION_VARIABLE ortp_cond_t;
-typedef SRWLOCK ortp_mutex_t;
-#else
+#ifdef ORTP_WINDOWS_DESKTOP
 typedef HANDLE ortp_cond_t;
 typedef HANDLE ortp_mutex_t;
+#else
+typedef CONDITION_VARIABLE ortp_cond_t;
+typedef SRWLOCK ortp_mutex_t;
 #endif
 typedef HANDLE ortp_thread_t;
 
 #define ortp_thread_create	WIN_thread_create
 #define ortp_thread_join	WIN_thread_join
+#define ortp_thread_self	WIN_thread_self
 #define ortp_thread_exit(arg)
 #define ortp_mutex_init		WIN_mutex_init
 #define ortp_mutex_lock		WIN_mutex_lock
@@ -188,6 +206,7 @@ ORTP_PUBLIC int WIN_mutex_unlock(ortp_mutex_t *mutex);
 ORTP_PUBLIC int WIN_mutex_destroy(ortp_mutex_t *mutex);
 ORTP_PUBLIC int WIN_thread_create(ortp_thread_t *t, void *attr_unused, void *(*func)(void*), void *arg);
 ORTP_PUBLIC int WIN_thread_join(ortp_thread_t thread, void **unused);
+ORTP_PUBLIC unsigned long WIN_thread_self(void);
 ORTP_PUBLIC int WIN_cond_init(ortp_cond_t *cond, void *attr_unused);
 ORTP_PUBLIC int WIN_cond_wait(ortp_cond_t * cond, ortp_mutex_t * mutex);
 ORTP_PUBLIC int WIN_cond_signal(ortp_cond_t * cond);
@@ -199,7 +218,7 @@ ORTP_PUBLIC int WIN_cond_destroy(ortp_cond_t * cond);
 #endif
 
 #define SOCKET_OPTION_VALUE	char *
-#define inline			__inline
+#define ORTP_INLINE			__inline
 
 #if defined(_WIN32_WCE)
 
@@ -228,12 +247,16 @@ const char * ortp_strerror(DWORD value);
 #endif
 
 ORTP_PUBLIC const char *getWinSocketError(int error);
+#ifndef getSocketErrorCode
 #define getSocketErrorCode() WSAGetLastError()
+#endif
+#ifndef getSocketError
 #define getSocketError() getWinSocketError(WSAGetLastError())
+#endif
 
-#define snprintf _snprintf
-#define strcasecmp _stricmp
-#define strncasecmp _strnicmp
+#ifndef F_OK
+#define F_OK 00 /* Visual Studio does not define F_OK */
+#endif
 
 
 #ifdef __cplusplus
@@ -249,12 +272,17 @@ char * WSAAPI gai_strerror(int errnum);
 
 #endif
 
+#ifndef _BOOL_T_
+#define _BOOL_T_
 typedef unsigned char bool_t;
+#endif /* _BOOL_T_ */
 #undef TRUE
 #undef FALSE
 #define TRUE 1
 #define FALSE 0
 
+typedef struct _OList OList;
+
 typedef struct ortpTimeSpec{
 	int64_t tv_sec;
 	int64_t tv_nsec;
@@ -288,14 +316,22 @@ ORTP_PUBLIC int set_non_blocking_socket(ortp_socket_t sock);
 ORTP_PUBLIC char *ortp_strndup(const char *str,int n);
 ORTP_PUBLIC char *ortp_strdup_printf(const char *fmt,...);
 ORTP_PUBLIC char *ortp_strdup_vprintf(const char *fmt, va_list ap);
+ORTP_PUBLIC char *ortp_strcat_printf(char *dst, const char *fmt,...);
+ORTP_PUBLIC char *ortp_strcat_vprintf(char *dst, const char *fmt, va_list ap);
 
 ORTP_PUBLIC int ortp_file_exist(const char *pathname);
 
 ORTP_PUBLIC void ortp_get_cur_time(ortpTimeSpec *ret);
+void _ortp_get_cur_time(ortpTimeSpec *ret, bool_t realtime);
+ORTP_PUBLIC uint64_t ortp_get_cur_time_ms(void);
+ORTP_PUBLIC void ortp_sleep_ms(int ms);
+ORTP_PUBLIC void ortp_sleep_until(const ortpTimeSpec *ts);
+ORTP_PUBLIC int ortp_timespec_compare(const ortpTimeSpec *s1, const ortpTimeSpec *s2);
+ORTP_PUBLIC unsigned int ortp_random(void);
 
 /* portable named pipes  and shared memory*/
 #if !defined(_WIN32_WCE)
-#ifdef WIN32
+#ifdef _WIN32
 typedef HANDLE ortp_pipe_t;
 #define ORTP_PIPE_INVALID INVALID_HANDLE_VALUE
 #else
@@ -322,6 +358,9 @@ ORTP_PUBLIC int ortp_pipe_write(ortp_pipe_t p, const uint8_t *buf, int len);
 ORTP_PUBLIC void *ortp_shm_open(unsigned int keyid, int size, int create);
 ORTP_PUBLIC void ortp_shm_close(void *memory);
 
+ORTP_PUBLIC	bool_t ortp_is_multicast_addr(const struct sockaddr *addr);
+	
+	
 #endif
 
 #ifdef __cplusplus
@@ -330,7 +369,7 @@ ORTP_PUBLIC void ortp_shm_close(void *memory);
 #endif
 
 
-#if (defined(WIN32) || defined(_WIN32_WCE)) && !defined(ORTP_STATIC)
+#if (defined(_WIN32) || defined(_WIN32_WCE)) && !defined(ORTP_STATIC)
 #ifdef ORTP_EXPORTS
    #define ORTP_VAR_PUBLIC    extern __declspec(dllexport)
 #else
@@ -340,6 +379,9 @@ ORTP_PUBLIC void ortp_shm_close(void *memory);
    #define ORTP_VAR_PUBLIC    extern
 #endif
 
+#ifndef IN6_IS_ADDR_MULTICAST
+#define IN6_IS_ADDR_MULTICAST(i)	(((uint8_t *) (i))[0] == 0xff)
+#endif
 
 /*define __ios when we are compiling for ios.
  The TARGET_OS_IPHONE macro is stupid, it is defined to 0 when compiling on mac os x.
