@@ -171,7 +171,6 @@ PayloadType payload_type_lpc1016={
 	FLAGS(0)
 };
 
-
 PayloadType payload_type_gsm={
 	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(8000),
@@ -458,6 +457,7 @@ void av_profile_init(RtpProfile *profile)
 {
 	rtp_profile_clear_all(profile);
 	profile->name="AV profile";
+	
 	rtp_profile_set_payload(profile,0,&payload_type_pcmu8000);
 	rtp_profile_set_payload(profile,1,&payload_type_lpc1016);
 	rtp_profile_set_payload(profile,3,&payload_type_gsm);
@@ -472,8 +472,7 @@ void av_profile_init(RtpProfile *profile)
 	rtp_profile_set_payload(profile,31,&payload_type_h261);
 	rtp_profile_set_payload(profile,32,&payload_type_mpv);
 	rtp_profile_set_payload(profile,34,&payload_type_h263);
-	rtp_profile_set_payload(profile,96,&payload_type_t140);
-	rtp_profile_set_payload(profile,97,&payload_type_t140_red);
+
 }
 
 /* these are extra payload types that can be used dynamically */
@@ -507,6 +506,21 @@ PayloadType payload_type_speex_nb={
 	FLAGS(PAYLOAD_TYPE_IS_VBR)
 };
 
+PayloadType payload_type_bv16={
+	TYPE(PAYLOAD_AUDIO_PACKETIZED),
+	CLOCK_RATE(8000),
+	BITS_PER_SAMPLE(0),
+	ZERO_PATTERN(NULL),
+	PATTERN_LENGTH(0),
+	NORMAL_BITRATE(16000),/* 5ms / 80 bits per frame */
+	MIME_TYPE("BV16"),
+	CHANNELS(1),
+	RECV_FMTP(NULL),
+	SEND_FMTP(NULL),
+	NO_AVPF,
+	FLAGS(0)
+};
+
 PayloadType payload_type_speex_wb={
 	TYPE(PAYLOAD_AUDIO_PACKETIZED),
 	CLOCK_RATE(16000),
@@ -604,7 +618,7 @@ PayloadType payload_type_mp4v={
 	CHANNELS(0),
 	RECV_FMTP(NULL),
 	SEND_FMTP(NULL),
-	NO_AVPF,
+	AVPF(PAYLOAD_TYPE_AVPF_FIR | PAYLOAD_TYPE_AVPF_PLI, RTCP_DEFAULT_REPORT_INTERVAL),
 	FLAGS(0)
 };
 
