@@ -22,6 +22,7 @@
 #include "ortp-config.h"
 #endif
 #include "ortp/ortp.h"
+#include "utils.h"
 #include <inttypes.h>
 #include "scheduler.h"
 
@@ -37,7 +38,7 @@ RtpScheduler *__ortp_scheduler;
 
 extern void av_profile_init(RtpProfile *profile);
 
-static void init_random_number_generator(){
+static void init_random_number_generator(void){
 #ifndef _WIN32
 	struct timeval t;
 	ortp_gettimeofday(&t,NULL);
@@ -76,7 +77,7 @@ void ortp_init()
 #ifdef _WIN32
 	win32_init_sockets();
 #endif
-
+	ortp_init_logger();
 	av_profile_init(&av_profile);
 	ortp_global_stats_reset();
 	init_random_number_generator();
@@ -87,7 +88,7 @@ void ortp_init()
 
 /**
  *	Initialize the oRTP scheduler. You only have to do that if you intend to use the
- *	scheduled mode of the #RtpSession in your application.
+ *	scheduled mode of the RtpSession in your application.
  *
 **/
 void ortp_scheduler_init()
@@ -127,6 +128,7 @@ void ortp_exit()
 			rtp_scheduler_destroy(__ortp_scheduler);
 			__ortp_scheduler=NULL;
 		}
+		ortp_uninit_logger();
 	}
 }
 
@@ -167,6 +169,8 @@ void rtp_stats_display(const rtp_stats_t *stats, const char *header) {
 	ortp_log(ORTP_MESSAGE, "incoming received too late           %10"PRId64" packets", stats->outoftime);
 	ortp_log(ORTP_MESSAGE, "incoming bad formatted               %10"PRId64" packets", stats->bad);
 	ortp_log(ORTP_MESSAGE, "incoming discarded (queue overflow)  %10"PRId64" packets", stats->discarded);
+	ortp_log(ORTP_MESSAGE, "sent rtcp                            %10"PRId64" packets", stats->sent_rtcp_packets);
+	ortp_log(ORTP_MESSAGE, "received rtcp                        %10"PRId64" packets", stats->recv_rtcp_packets);
 	ortp_log(ORTP_MESSAGE, "===========================================================");
 }
 
