@@ -57,7 +57,8 @@ mblk_t * rtp_getq(queue_t *q, uint32_t ts, int *rejected);
 int rtp_session_rtp_recv(RtpSession * session, uint32_t ts);
 int rtp_session_rtcp_recv(RtpSession * session);
 int rtp_session_rtp_send (RtpSession * session, mblk_t * m);
-int rtp_session_rtcp_send (RtpSession * session, mblk_t * m);
+
+#define rtp_session_rtcp_send rtp_session_rtcp_sendm_raw
 
 void rtp_session_rtp_parse(RtpSession *session, mblk_t *mp, uint32_t local_str_ts, struct sockaddr *addr, socklen_t addrlen);
 
@@ -86,6 +87,29 @@ void ortp_stream_clear_aux_addresses(OrtpStream *os);
  * */
 void rtp_session_set_transports(RtpSession *session, RtpTransport *rtptr, RtpTransport *rtcptr);
 
-ORTP_PUBLIC bool_t rtp_profile_is_telephone_event(const RtpProfile *prof, int pt);
+bool_t rtp_profile_is_telephone_event(const RtpProfile *prof, int pt);
+
+ortp_socket_t rtp_session_get_socket(RtpSession *session, bool_t is_rtp);
+
+void rtp_session_do_splice(RtpSession *session, mblk_t *packet, bool_t is_rtp);
+
+/*
+ * Update remote addr in the following case:
+ * rtp symetric == TRUE && socket not connected && remote addr has changed && ((rtp/rtcp packet && not only at start) or (no rtp/rtcp packets received))
+ * @param[in] session  on which to perform change
+ * @param[in] mp packet where remote addr is retreived
+ * @param[in] is_rtp true if rtp
+ * @param[in] only_at_start only perform changes if no valid packets received yet
+ * @return 0 if chaged was performed
+ *
+ */
+	
+int rtp_session_update_remote_sock_addr(RtpSession * session, mblk_t * mp, bool_t is_rtp,bool_t only_at_start);
+
+void rtp_session_process_incoming(RtpSession * session, mblk_t *mp, bool_t is_rtp_packet, uint32_t ts, bool_t received_via_rtcp_mux);
+void update_sent_bytes(OrtpStream *os, int nbytes);
+
+void _rtp_session_apply_socket_sizes(RtpSession *session);
+
 
 #endif
